==> nextcloud-26.0.7.tar.bz2: nextcloud/apps/comments/l10n/pl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentarze",
    "You commented" : "Skomentowałeś",
    "{author} commented" : "{author} skomentował",
    "You commented on %1$s" : "Skomentowałeś w %1$s",
    "You commented on {file}" : "Skomentowałeś w {file}",
    "%1$s commented on %2$s" : "%1$s skomentował %2$s",
    "{author} commented on {file}" : "{author} skomentował w {file}‭",
    "<strong>Comments</strong> for files" : "<strong>Komentarze</strong> dla plików",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Wspomniano o Tobie w komentarzu w \"{file}\" przez użytkownika, który został usunięty",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} wspomniał o Tobie w komentarzu do “{file}”",
    "Files app plugin to add comments to files" : "Plugin umożliwiający dodawanie komentarzy w aplikacji Pliki",
    "Edit comment" : "Edytuj komentarz",
    "Delete comment" : "Usuń komentarz",
    "Cancel edit" : "Anuluj edycję",
    "Post comment" : "Wyślij komentarz",
    "No comments yet, start the conversation!" : "Brak komentarzy, rozpocznij rozmowę!",
    "No more messages" : "Nie ma więcej wiadomości",
    "Retry" : "Powtórz",
    "Unable to load the comments list" : "Nie można załadować listy komentarzy",
    "_1 new comment_::_{unread} new comments_" : ["{unread} nowy komentarz","{unread} nowe komentarze","{unread} nowych komentarzy","{unread} nowe komentarze"],
    "Comment" : "Komentarz",
    "An error occurred while trying to edit the comment" : "Wystąpił błąd podczas próby edycji komentarza",
    "Comment deleted" : "Komentarz usunięty",
    "An error occurred while trying to delete the comment" : "Wystąpił błąd podczas próby usunięcia komentarza",
    "An error occurred while trying to create the comment" : "Wystąpił błąd podczas próby utworzenia komentarza",
    "%1$s commented" : "%1$s skomentował",
    "_%n unread comment_::_%n unread comments_" : ["%n nieprzeczytany komentarz","%n nieprzeczytane komentarze","%n nieprzeczytanych komentarzy","%n nieprzeczytanych komentarzy"]
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-29.0.12.tar.bz2: nextcloud/apps/comments/l10n/pl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentarze",
    "You commented" : "Skomentowałeś",
    "{author} commented" : "{author} skomentował",
    "You commented on %1$s" : "Skomentowałeś w %1$s",
    "You commented on {file}" : "Skomentowałeś w {file}",
    "%1$s commented on %2$s" : "%1$s skomentował %2$s",
    "{author} commented on {file}" : "{author} skomentował w {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentarze</strong> dla plików",
    "Files" : "Pliki",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Wspomniano o Tobie w „{file}” w komentarzu konta, które zostało już usunięte",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} wspomniał o Tobie w komentarzu do “{file}”",
    "Files app plugin to add comments to files" : "Plugin umożliwiający dodawanie komentarzy w aplikacji Pliki",
    "Edit comment" : "Edytuj komentarz",
    "Delete comment" : "Usuń komentarz",
    "Cancel edit" : "Anuluj edycję",
    "New comment" : "Nowy komentarz",
    "Write a comment …" : "Napisz komentarz…",
    "Post comment" : "Wyślij komentarz",
    "@ for mentions, : for emoji, / for smart picker" : "@ dla wzmianek, : dla emoji, / dla inteligentnego wybierania",
    "Could not reload comments" : "Nie można ponownie wczytać komentarzy",
    "No comments yet, start the conversation!" : "Brak komentarzy, rozpocznij rozmowę!",
    "No more messages" : "Nie ma więcej wiadomości",
    "Retry" : "Powtórz",
    "Failed to mark comments as read" : "Nie udało się oznaczyć komentarzy jako przeczytane",
    "Unable to load the comments list" : "Nie można załadować listy komentarzy",
    "_1 new comment_::_{unread} new comments_" : ["{unread} nowy komentarz","{unread} nowe komentarze","{unread} nowych komentarzy","{unread} nowe komentarze"],
    "Comment" : "Komentarz",
    "An error occurred while trying to edit the comment" : "Wystąpił błąd podczas próby edycji komentarza",
    "Comment deleted" : "Komentarz usunięty",
    "An error occurred while trying to delete the comment" : "Wystąpił błąd podczas próby usunięcia komentarza",
    "An error occurred while trying to create the comment" : "Wystąpił błąd podczas próby utworzenia komentarza"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
